@@ -23,7 +23,8 @@
 
 #include <inttypes.h>
 
-#include <pulsecore/typedefs.h>
+typedef struct pa_sink_input pa_sink_input;
+
 #include <pulse/sample.h>
 #include <pulse/format.h>
 #include <pulsecore/memblockq.h>
